iSulad/0169-2293-reduce-epoll-loop-timeout-time.patch
openeuler-sync-bot 955d185c18 !645 [sync] PR-641: upgrade from upstream
* upgrade from upstream
2023-12-22 01:09:39 +00:00

29 lines
1.1 KiB
Diff

From 6c4bbe725a460cff7f08f2855ebdf393a6e69fa1 Mon Sep 17 00:00:00 2001
From: zhongtao <zhongtao17@huawei.com>
Date: Tue, 5 Dec 2023 03:35:51 +0000
Subject: [PATCH 169/181] !2293 reduce epoll loop timeout time * reduce epoll
loop timeout time
---
src/cmd/isulad-shim/process.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/cmd/isulad-shim/process.c b/src/cmd/isulad-shim/process.c
index c205302f..9cd40089 100644
--- a/src/cmd/isulad-shim/process.c
+++ b/src/cmd/isulad-shim/process.c
@@ -599,8 +599,8 @@ static void *io_epoll_loop(void *data)
// use a timeout epoll loop to ensure complete data reception
// th second epoll_loop will exit in the following scenarios:
// 1. both stdout fd and stderr fd failed to read
- // 2. no event received within 3000 milliseconds
- ret = epoll_loop(&descr, 3000);
+ // 2. no event received within 100 milliseconds
+ ret = epoll_loop(&descr, 100);
if (ret != 0) {
write_message(ERR_MSG, "Repeat the epoll loop to ensure that all data is transferred");
}
--
2.42.0